<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// M
	'mots_description' => 'Ключи и группы ключей',
	'mots_slogan' => 'Настройка ключей и групп ключей в SPIP',
];
